@@ -9,13 +9,13 @@ from trytond import backend
 from trytond.config import config
 
 __all__ = ['Employee', 'EmployeeCostPrice', 'price_digits']
-__metaclass__ = PoolMeta
 
 price_digits = (16, config.getint(
         'timesheet_cost', 'price_decimal', default=4))
 
 
 class Employee:
+    __metaclass__ = PoolMeta
     __name__ = 'company.employee'
     cost_price = fields.Function(fields.Numeric('Cost Price',
             digits=price_digits,
@@ -82,9 +82,8 @@ class EmployeeCostPrice(ModelSQL, ModelView):
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
         super(EmployeeCostPrice, cls).__register__(module_name)
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
 
         # Migration from 2.8 drop date_cost_price_uniq
         table.drop_constraint('date_cost_price_uniq')
